| Title: | Forest Attributes in U.S. States |
|---|---|
| Description: | A small subset of plots throughout the U.S. are sampled and assessed "on-the-ground" as forested or non-forested by the U.S. Department of Agriculture, Forest Service, Forest Inventory and Analysis (FIA) Program, but the FIA also has access to remotely sensed data for all land in the country. The 'forested' package contains data frames intended for use in predictive modeling applications where the more easily-accessible remotely sensed data can be used to predict whether a plot is forested or non-forested. Currently, the package provides data for Washington and Georgia. |
| Authors: | Grayson White [aut] (ORCID: <https://orcid.org/0000-0003-4993-2792>), Hannah Frick [aut] (ORCID: <https://orcid.org/0000-0002-6049-5258>), Simon Couch [aut, cre] (ORCID: <https://orcid.org/0000-0001-5676-5107>), Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Simon Couch <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0.9000 |
| Built: | 2026-06-03 08:41:49 UTC |
| Source: | https://github.com/simonpcouch/forested |
The U.S. Department of Agriculture, Forest Service, Forest Inventory and Analysis (FIA) Program provides all sorts of estimates of forest attributes for uses in research, legislation, and land management. The FIA uses a set of criteria to classify a plot of land as "forested" or "non-forested," and that classification is a central data point in many decision-making contexts. A small subset of plots in the U.S. are sampled and assessed "on-the-ground" as forested or non-forested, but the FIA has access to remotely sensed data for all land in the country. Practitioners can develop a model on the more easily-accessible remotely sensed data to predict whether a plot is forested or non-forested.
forested forested_wa forested_gaforested forested_wa forested_ga
A data frame with:
Whether the plot is classified as "forested" or not,
as a factor with levels "Yes" and "No".
Year when the plot was classified "on-the-ground" as forested or not. The remaining, remotely-sensed variables are measured at different times or averaged over multiple years.
Elevation, in meters.
Transformed aspect degrees to eastness (-100 to 100).
Transformed aspect degrees to northness (-100 to 100).
Degree of irregularity of the plot.
LANDFIRE tree/non-tree lifeform mask, as a factor
with levels "Tree" and "No tree".
Mean annual dewpoint temperature (1991-2020), in degrees Celsius.
Mean annual precipitation (1991-2020), in mm × 100.
Mean annual temperature (1991-2020), in degrees Celsius.
Mean annual minimum temperature (1991-2020), in degrees Celsius.
Mean annual maximum temperature (1991-2020), in degrees Celsius.
Mean minimum temperature in January (1991-2020), in degrees Celsius.
Minimum and maximum annual vapor pressure deficit (1991-2020), in Pa x 100.
Analytical Tree Canopy Cover, as a percent.
The longitude and latitude of the center of the plot with a slight perturbation.
Land cover type from European Space Agency (ESA) 2020
WorldCover global land cover product, as a factor with levels
"Tree", "Non-tree vegetation", and "Barren".
The county in the state, as a factor.
The number of rows varies by state. Washington has 7107 rows, Georgia has 10937.
The Georgia data has one less column than the Washington data as its
northness column has been omitted due to issues with the source raster.
An object of class tbl_df (inherits from tbl, data.frame) with 7107 rows and 20 columns.
An object of class tbl_df (inherits from tbl, data.frame) with 10937 rows and 19 columns.
The forested package provides a few data sets, each corresponding to forest data in one state:
forested corresponds to Washington state and is aliased as forested_wa.
forested_ga corresponds to Georgia.
For more information on the source data, see Table 1 in:
White, Grayson W.; Yamamoto, Josh K.; Elsyad, Dinan H.; Schmitt, Julian F.; Korsgaard, Niels H.; Hu, Jie Kate; Gaines III, George C.; Frescino Tracey S.; McConville, Kelly S. (2025). Small area estimation of forest biomass via a two-stage model for continuous zero-inflated data. Canadian Journal of Forest Research: 55: 1-19. (ver. 1.0).
For more on data definitions:
White, Grayson W.; Wieczorek, Jerzy A.; Cody, Zachariah W.; Tan, Emily X.; Chistolini, Jacqueline O.; McConville, Kelly S.; Frescino, Tracey S.; Moisen, Gretchen G. (2025). A method for empirically assessing small area estimators via bootstrap-weighted k-nearest-neighbor artificial populations, with applications to forest inventory. Forestry: An International Journal of Forest Research: cpaf071 (ver. 1.0).
Source data pre-preprocessed using the FIESTA R Package (GPL-3):
Frescino, Tracey S.; Moisen, Gretchen G.; Patterson, Paul L.; Toney, Chris; White, Grayson W. (2023). FIESTA: A forest inventory estimation and analysis R package. Ecography 2023: e06428 (ver. 1.0).
# Washington data: str(forested) head(forested) all.equal(forested, forested_wa) # Georgia data: str(forested_ga) head(forested_ga)# Washington data: str(forested) head(forested) all.equal(forested, forested_wa) # Georgia data: str(forested_ga) head(forested_ga)